gs_quant.timeseries.analysis.last_value — gs_quant 0.1 documentation

# gs_quant.timeseries.analysis.last_value

`last_value`(x)

  Last value of series (as a scalar)

  Parameters

    x (`Series`) – time series

  Return type

    `Union`[`int`, `float`]

  Returns

    last value

  Usage

  Return a scalar value \(X_T\) where T is the last index value in the series.

  Examples

  Last value of series:

      >>> series = generate_series(100)
      >>> lv = last_value(series)

  See also

  `last()`